Skip to contents

This object is a character vector holding the schema used to validate the metadata line of a Dataset NDJSON file. It is the CDISC-published schema with three definitions hoisted into $defs so that the references to them resolve; see data-raw/data.R.

Usage

schema_ndjson_1_1_0

Format

schema_ndjson_1_1_0

A character vector with 1 element